@@ -36,8 +36,8 @@
 #' \insertRef{lian2018bayesian}{NMADiagT}
 #' @export
 nmadt.hsroc=function(nstu, K, data, testname, directory= NULL, eta=0, xi_preci=1.25, digits = 4,
-                     n.adapt = 5000, n.iter = 50000, n.burnin = floor(n.iter/2),
-                     n.chains = 3, n.thin = max(1, floor((n.iter - n.burnin)/1e+05)),
+                     n.adapt = 5000, n.iter = 50000, n.chains = 3,
+                     n.burnin = floor(n.iter/2), n.thin = max(1, floor((n.iter - n.burnin)/1e+05)),
                      conv.diag = FALSE, trace = NULL, dic = FALSE, mcmc.samples = FALSE )
 {
   #options(warn = 1)
@@ -69,7 +69,7 @@ nmadt.hsroc=function(nstu, K, data, testname, directory= NULL, eta=0, xi_preci=1
     stop("missing indicator not in the right format(0 for missing data and 1 for nonmissing data)" )
   }
   y<-data[c((K+3):(2*K+3))]
-
+  sid<-data[,1]
   n<-as.data.frame(data[,ncol(data)])
 
   if(any(is.na(delta))){
@@ -92,8 +92,8 @@ nmadt.hsroc=function(nstu, K, data, testname, directory= NULL, eta=0, xi_preci=1
       stop("at least one effect size in argument trace is not available.")
   }
 
-  sid <- c(rep(c(1:nstu),each=4))
-  monitor<-c("post.se","post.sp","beta","mu1","mu2","post.pi","loglik_dic","theta","alpha","Se","Sp","pi","stud.se","stud.sp",'ppv','npv','LRpos','LRneg')
+
+  monitor<-c("post.se","post.sp","beta","mu1","mu2","post.pi","loglik_dic","theta","alpha","pi","stud.se","stud.sp",'ppv','npv','LRpos','LRneg')
   data.jags <- list('n' = n, 'delta'=delta,'N' = N,'y'=y,'K'=K,'R1'=R1,'R2'=R2,'nstu'=nstu,'sid'=sid,'eta'=eta, 'xi_preci'=xi_preci)
   #rng.seeds <- sample(1e+06, n.chains)
   init<-list()
